loop_empty: Check if later loop is empty

View source: R/later.R

loop_emptyR Documentation

Check if later loop is empty

Description

Returns true if there are currently no callbacks that are scheduled to execute in the present or future.

Usage

loop_empty(loop = current_loop())

Arguments

loop

A handle to an event loop.


later documentation built on March 5, 2026, 9:07 a.m.